ProSHADE: ProSHADE_exception Class Reference

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

Public Member Functions | List of all members
ProSHADE_exception Class Reference

This class is the representation of ProSHADE exception. More...

`#include <ProSHADE_exceptions.hpp>`

Inheritance diagram for ProSHADE_exception:

## Public Member Functions
| ProSHADE_exception (const char *msg, std::string errc_, std::string file_, unsigned int line_, std::string func_, std::string info_)
std::string | get_errc (void) const
std::string | get_file (void) const
unsigned int | get_line (void) const
std::string | get_func (void) const
std::string | get_info (void) const

## Detailed Description

This class is the representation of ProSHADE exception.

An object of this class is thrown whenever ProSHADE encounters exceptional case and needs handling it in unusual manner. It is a slight expansion on the usual C++ extension class.

Definition at line 36 of file ProSHADE_exceptions.hpp.

The documentation for this class was generated from the following file:

- src/proshade/ProSHADE_exceptions.hpp